@@ -1,5 +1,5 @@
-from cgdb.recources.flag import Flag
-from cgdb.recources.flagsList import FlagList
+from cgdb.resources.flag import Flag
+from cgdb.resources.flagsList import FlagList
 from cgdb.utils.ManagerMix import ManagerMix
 
 
